@@ -6,9 +6,10 @@ import (
 	"os/exec"
 	"os/user"
 	"path/filepath"
+	"runtime"
 	"strconv"
 
-	. "github.com/containers/podman/v4/test/utils"
+	. "github.com/containers/podman/v5/test/utils"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	. "github.com/onsi/gomega/gexec"
@@ -151,23 +152,15 @@ var _ = Describe("Podman Info", func() {
 	})
 
 	It("Podman info: check desired network backend", func() {
-		// defined in .cirrus.yml
-		want := os.Getenv("CI_DESIRED_NETWORK")
-		if want == "" {
-			if os.Getenv("CIRRUS_CI") == "" {
-				Skip("CI_DESIRED_NETWORK is not set--this is OK because we're not running under Cirrus")
-			}
-			Fail("CIRRUS_CI is set, but CI_DESIRED_NETWORK is not! See #16389")
-		}
 		session := podmanTest.Podman([]string{"info", "--format", "{{.Host.NetworkBackend}}"})
 		session.WaitWithDefaultTimeout()
 		Expect(session).To(ExitCleanly())
-		Expect(session.OutputToString()).To(Equal(want))
+		Expect(session.OutputToString()).To(Equal("netavark"))
 
 		session = podmanTest.Podman([]string{"info", "--format", "{{.Host.NetworkBackendInfo.Backend}}"})
 		session.WaitWithDefaultTimeout()
 		Expect(session).To(ExitCleanly())
-		Expect(session.OutputToString()).To(Equal(want))
+		Expect(session.OutputToString()).To(Equal("netavark"))
 	})
 
 	It("Podman info: check desired database backend", func() {
@@ -185,6 +178,69 @@ var _ = Describe("Podman Info", func() {
 		Expect(session.OutputToString()).To(Equal(want))
 	})
 
+	It("podman --db-backend info basic check", Serial, func() {
+		SkipIfRemote("--db-backend only supported on the local client")
+
+		const desiredDB = "CI_DESIRED_DATABASE"
+
+		type argWant struct {
+			arg  string
+			want string
+		}
+		backends := []argWant{
+			// default should be sqlite
+			{arg: "", want: "sqlite"},
+			{arg: "boltdb", want: "boltdb"},
+			// now because a boltdb exists it should use boltdb when default is requested
+			{arg: "", want: "boltdb"},
+			{arg: "sqlite", want: "sqlite"},
+			// just because we requested sqlite doesn't mean it stays that way.
+			// once a boltdb exists, podman will forevermore stick with it
+			{arg: "", want: "boltdb"},
+		}
+
+		for _, tt := range backends {
+			oldDesiredDB := os.Getenv(desiredDB)
+			if tt.arg == "boltdb" {
+				err := os.Setenv(desiredDB, "boltdb")
+				Expect(err).To(Not(HaveOccurred()))
+				defer os.Setenv(desiredDB, oldDesiredDB)
+			}
+
+			session := podmanTest.Podman([]string{"--db-backend", tt.arg, "--log-level=info", "info", "--format", "{{.Host.DatabaseBackend}}"})
+			session.WaitWithDefaultTimeout()
+			Expect(session).To(Exit(0))
+			Expect(session.OutputToString()).To(Equal(tt.want))
+			Expect(session.ErrorToString()).To(ContainSubstring("Using %s as database backend", tt.want))
+
+			if tt.arg == "boltdb" {
+				err := os.Setenv(desiredDB, oldDesiredDB)
+				Expect(err).To(Not(HaveOccurred()))
+			}
+		}
+
+		// make sure we get an error for bogus values
+		session := podmanTest.Podman([]string{"--db-backend", "bogus", "info", "--format", "{{.Host.DatabaseBackend}}"})
+		session.WaitWithDefaultTimeout()
+		Expect(session).To(Exit(125))
+		Expect(session.ErrorToString()).To(Equal("Error: unsupported database backend: \"bogus\""))
+	})
+
+	It("Podman info: check desired storage driver", func() {
+		// defined in .cirrus.yml
+		want := os.Getenv("CI_DESIRED_STORAGE")
+		if want == "" {
+			if os.Getenv("CIRRUS_CI") == "" {
+				Skip("CI_DESIRED_STORAGE is not set--this is OK because we're not running under Cirrus")
+			}
+			Fail("CIRRUS_CI is set, but CI_DESIRED_STORAGE is not! See #20161")
+		}
+		session := podmanTest.Podman([]string{"info", "--format", "{{.Store.GraphDriverName}}"})
+		session.WaitWithDefaultTimeout()
+		Expect(session).To(ExitCleanly())
+		Expect(session.OutputToString()).To(Equal(want), ".Store.GraphDriverName from podman info")
+	})
+
 	It("Podman info: check lock count", Serial, func() {
 		// This should not run on architectures and OSes that use the file locks backend.
 		// Which, for now, is Linux + RISCV and FreeBSD, neither of which are in CI - so
@@ -210,4 +266,16 @@ var _ = Describe("Podman Info", func() {
 		// Don't check absolute numbers because there is a decent chance of contamination, containers that were never removed properly, etc.
 		Expect(free1).To(Equal(free2 + 1))
 	})
+
+	It("Podman info: check for client information when no system service", func() {
+		// the output for this information is not really something we can marshall
+		want := runtime.GOOS + "/" + runtime.GOARCH
+		podmanTest.StopRemoteService()
+		SkipIfNotRemote("Specifically testing a failed remote connection")
+		info := podmanTest.Podman([]string{"info"})
+		info.WaitWithDefaultTimeout()
+		Expect(info.OutputToString()).To(ContainSubstring(want))
+		Expect(info).ToNot(ExitCleanly())
+		podmanTest.StartRemoteService() // Start service again so teardown runs clean
+	})
 })
